summaryrefslogtreecommitdiff
path: root/indoteknik_custom/models/purchase_pricelist.py
diff options
context:
space:
mode:
authorAzka Nathan <darizkyfaz@gmail.com>2024-11-16 09:15:42 +0700
committerAzka Nathan <darizkyfaz@gmail.com>2024-11-16 09:15:42 +0700
commit528a737f696b371faa4ede6e5044c84ad3e4785e (patch)
tree379adea74fc8a7ce1d09523e62d56f34cf9d181d /indoteknik_custom/models/purchase_pricelist.py
parentafc8a108c9b1c52656bb3bbac9111dfa6e590bcb (diff)
ppn 12%
Diffstat (limited to 'indoteknik_custom/models/purchase_pricelist.py')
-rwxr-xr-xindoteknik_custom/models/purchase_pricelist.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/indoteknik_custom/models/purchase_pricelist.py b/indoteknik_custom/models/purchase_pricelist.py
index e5b35d7f..c543070a 100755
--- a/indoteknik_custom/models/purchase_pricelist.py
+++ b/indoteknik_custom/models/purchase_pricelist.py
@@ -48,9 +48,9 @@ class PurchasePricelist(models.Model):
def _constrains_include_price(self):
price, taxes = self._get_valid_price()
# When have tax is excluded or empty tax, then multiply by 1.11
if (taxes and not taxes.price_include) or not taxes:
- price *= 1.11
+ price *= 1.12
self.include_price = price
@@ -48,9 +48,9 @@ class PurchasePricelist(models.Model):
def _constrains_include_price(self):
price, taxes = self._get_valid_price()
- # When have tax is excluded or empty tax, then multiply by 1.11
+ # When have tax is excluded or empty tax, then multiply by 1.12
if (taxes and not taxes.price_include) or not taxes: